@@ -9,14 +9,16 @@ from __future__ import unicode_literals
 import typing
 
 from .base import Opener
+from .registry import registry
 from .errors import NotWriteable
 
-if False:  # typing.TYPE_CHECKING
+if typing.TYPE_CHECKING:
     from typing import Text
     from .parse import ParseResult
-    from ..tarfs import TarFS
+    from ..tarfs import TarFS  # noqa: F401
 
 
+@registry.install
 class TarOpener(Opener):
     """`TarFS` opener.
     """
